# B1 Models

## B1DAM

::: qmrpy.models.b1.B1DAM
    options:
      members:
        - __init__
        - fit
        - fit_image

## B1AFI

::: qmrpy.models.b1.B1AFI
    options:
      members:
        - __init__
        - fit
        - fit_image

## B1BlochSiegert

::: qmrpy.models.b1.B1BlochSiegert
    options:
      members:
        - __init__
        - fit
        - fit_image
        - forward
